slice

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 18, 2024 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RemoveDuplicateInt

func RemoveDuplicateInt(strSlice []int) []int

RemoveDuplicateInt removes all the duplicate integers and return a new slice without any duplicate values.

func RemoveDuplicateStr

func RemoveDuplicateStr(strSlice []string) []string

RemoveDuplicateStr removes all the duplicate strings and return a new slice without any duplicate values.

Types

This section is empty.

Jump to