structs

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 18, 2024 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Result

type Result struct {
	FieldName string
	OldValue  interface{}
	NewValue  interface{}
}

Result represents the comparison outcome of a field, including its name, old value, and new value.

func CompareStructs

func CompareStructs(old, new interface{}) ([]Result, error)

CompareStructs compares two struct instances of the same type and returns a list of results with the old and new values of each field tagged with `updateable`.

Jump to