Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Result ¶
type Result struct {
FieldName string
OldValue interface{}
NewValue interface{}
}
Result represents the comparison outcome of a field, including its name, old value, and new value.
func CompareStructs ¶
CompareStructs compares two struct instances of the same type and returns a list of results with the old and new values of each field tagged with `updateable`.
Click to show internal directories.
Click to hide internal directories.